The MPL Reference Manual: list_c

Front Page / Sequences / Classes / list_c

# list_c

### Description

`list_c` is an Integral Sequence Wrapper for list. As such, it shares all list characteristics and requirements, and differs only in the way the original sequence content is specified.

### Header

Sequence form | Header
--- | ---
Variadic | `#include <boost/mpl/list_c.hpp>`
Numbered | `#include <boost/mpl/list/list`n`_c.hpp>`

### Model of

- Integral Sequence Wrapper
- Variadic Sequence
- Forward Sequence
- Extensible Sequence
- Front Extensible Sequence

### Expression semantics

The semantics of an expression are defined only where they differ from, or are not defined in list.

Expression | Semantics
--- | ---
    list_c<T,c1,c2,... cn>
    listn_c<T,c1,c2,... cn>
| A list of integral constant wrappers `integral_c<T,`c1`>`, `integral_c<T,`c2`>`, ... `integral_c<T,`cn`>`; see Integral Sequence Wrapper.
    list_c<T,c1,c2,... cn>::type
    listn_c<T,c1,c2,... cn>::type
| Identical to `list`n`<` `integral_c<T,`c1`>`, `integral_c<T,`c2`>`, ... `integral_c<T,`cn`>` `>`; see Integral Sequence Wrapper.
    list_c<T,c1,c2,... cn>::value_type
    listn_c<T,c1,c2,... cn>::value_type
| Identical to `T`; see Integral Sequence Wrapper.

### Example

    typedef list_c<int,1,2,3,5,7,12,19,31> fibonacci;
    typedef push_front<fibonacci,int_<1> >::type fibonacci2;

    BOOST_MPL_ASSERT_RELATION( front<fibonacci2>::type::value, ==, 1 );

### See also

Sequences, Integral Sequence Wrapper, list, integral_c, vector_c, set_c, range_c